object of class ShortReadQ, such as the result of
function readFastq
method
string; passed on to function intPhred
batchSize
number of rows to process in each iteration; directly
influences RAM usage of this function
Value
A numeric vector of the median values per nucleotide position in the
reads. The length of this vector corresponds to the length of the
longest read in the data.
Details
The quality values are computed for each batch of reads and stored as
numeric Rle objects for each postion. In each iteration, the
Rle object of the current batch is merged with the previous one
in order to keep the RAM usage low.